# Script example

Contribution by Griatch, 2012

Example script for testing. This adds a simple timer that has your
character make small verbal observations at irregular intervals.

To test, use (in game)

    > script me = contrib.tutorials.bodyfunctions.BodyFunctions

## Notes

Use `scripts me` to see the script running on you. Note that even though
the timer ticks down to 0, you will _not_ see an echo every tick (it's
random if an echo is given on a tick or not).
